<?php
// Version: 2.0 Beta 4; index

/*	This template is, perhaps, the most important template in the theme. It
	contains the main template layer that displays the header and footer of
	the forum, namely with main_above and main_below. It also contains the
	menu sub template, which appropriately displays the menu; the init sub
	template, which is there to set the theme up; (init can be missing.) and
	the linktree sub template, which sorts out the link tree.

	The init sub template should load any data and set any hardcoded options.

	The main_above sub template is what is shown above the main content, and
	should contain anything that should be shown up there.

	The main_below sub template, conversely, is shown after the main content.
	It should probably contain the copyright statement and some other things.

	The linktree sub template should display the link tree, using the data
	in the $context['linktree'] variable.

	The menu sub template should display all the relevant buttons the user
	wants and or needs.

	For more information on the templating system, please see the site at:
	http://www.simplemachines.org/
*/

// Initialize the template... mainly little settings.
function template_init()
{
	global $context, $settings, $options, $txt;

	/* Use images from default theme when using templates from the default theme?
		if this is 'always', images from the default theme will be used.
		if this is 'defaults', images from the default theme will only be used with default templates.
		if this is 'never' or isn't set at all, images from the default theme will not be used. */
	$settings['use_default_images'] = 'never';

	/* What document type definition is being used? (for font size and other issues.)
		'xhtml' for an XHTML 1.0 document type definition.
		'html' for an HTML 4.01 document type definition. */
	$settings['doctype'] = 'xhtml';

	/* The version this template/theme is for.
		This should probably be the version of SMF it was created for. */
	$settings['theme_version'] = '2.0 Beta 3 Public';

	/* Set a setting that tells the theme that it can render the tabs. */
	$settings['use_tabs'] = true;

	/* Use plain buttons - as oppossed to text buttons? */
	$settings['use_buttons'] = true;

	/* Show sticky and lock status separate from topic icons? */
	$settings['separate_sticky_lock'] = true;

	/* Does this theme use the strict doctype? */
	$settings['strict_doctype'] = false;

	/* Does this theme use post previews on the message index? */
	$settings['message_index_preview'] = false;
	 
	// Color changer
	if(!$context['user']['is_guest'] && isset($_POST['options']['theme_color']))
	{
	   include_once($GLOBALS['sourcedir'] . '/Profile-Modify.php');
	   makeThemeChanges($context['user']['id'], $settings['theme_id']);
	   $options['theme_color'] = $_POST['options']['theme_color'];
	}
	elseif ($context['user']['is_guest'])
	{
	   if (isset($_POST['options']['theme_color']))
	   {
		  $_SESSION['theme_color'] = $_POST['options']['theme_color'];
		  $options['theme_color'] = $_SESSION['theme_color'];
	   }
	   elseif (isset($_SESSION['theme_color']))
		  $options['theme_color'] = $_SESSION['theme_color'];
	}


}

// The main sub template above the content.
function template_html_above()
{
	global $context, $settings, $options, $scripturl, $txt, $modSettings;

	// Show right to left and the character set for ease of translating.
	echo '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
      <html xmlns="http://www.w3.org/1999/xhtml"', $context['right_to_left'] ? ' dir="rtl"' : '', '><head>
	<meta http-equiv="Content-Type" content="text/html; charset=', $context['character_set'], '" />
	<meta name="description" content="', $context['page_title_html_safe'], '" />
	<meta name="keywords" content="', $context['meta_keywords'], '" />
	<script language="JavaScript" type="text/javascript" src="', $settings['default_theme_url'], '/scripts/script.js?rc1"></script>
	<script language="JavaScript" type="text/javascript" src="', $settings['default_theme_url'], '/scripts/theme.js?rc1"></script>
	<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[
		var smf_theme_url = "', $settings['theme_url'], '";
		var smf_default_theme_url = "', $settings['default_theme_url'], '";
		var smf_images_url = "', $settings['images_url'], '";
		var smf_scripturl = "', $scripturl, '";
		var smf_iso_case_folding = ', $context['server']['iso_case_folding'] ? 'true' : 'false', ';
		var smf_charset = "', $context['character_set'], '";', $context['show_pm_popup'] ? '
		if (confirm("' . $txt['show_personal_messages'] . '"))
			window.open(smf_prepareScriptUrl(smf_scripturl) + "action=pm");' : '', '
		var ajax_notification_text = "', $txt['ajax_in_progress'], '";
		var ajax_notification_cancel_text = "', $txt['modify_cancel'], '";
	// ]]></script>
	<title>', $context['page_title_html_safe'], '</title>';
	
	// Any color set by user?
	if (isset($options['theme_color']))
		$settings['theme_main_color'] = $options['theme_color'];

	// If not set, or if not allowed to set
	if(!isset($options['theme_color']) || (isset($settings['allow_color_change']) && $settings['allow_color_change'] == 'no'))
	{
		// Defaults.
		$options['theme_color'] = isset($settings['theme_main_color']) ? $settings['theme_main_color'] : '';
		$settings['theme_main_color'] = $options['theme_color'];
	}

	// Please don't index these Mr Robot.
	if (!empty($context['robot_no_index']))
		echo '
	<meta name="robots" content="noindex" />';

	// The ?rc1 part of this link is just here to make sure browsers don't cache it wrongly.
	echo '
	<link rel="stylesheet" type="text/css" href="', $settings['theme_url'], '/style', $context['theme_variant'], '.css?rc1" />
	<link rel="stylesheet" type="text/css" href="', $settings['theme_url'], '/' , $settings['theme_main_color'] , '.css?rc1" />
	<link rel="stylesheet" type="text/css" href="', $settings['default_theme_url'], '/print.css?fin11" media="print" />';

	echo '
	<link rel="stylesheet" type="text/css" href="', $settings['default_theme_url'], '/css/print.css?rc1" media="print" />';

	/* Internet Explorer 4/5 and Opera 6 just don't do font sizes properly. (they are big...)
		Thus, in Internet Explorer 4, 5, and Opera 6 this will show fonts one size smaller than usual.
		Note that this is affected by whether IE 6 is in standards compliance mode.. if not, it will also be big.
		Standards compliance mode happens when you use xhtml... */
	if ($context['browser']['needs_size_fix'])
		echo '
	<link rel="stylesheet" type="text/css" href="', $settings['default_theme_url'], '/css/fonts-compat.css" />';

	// Show all the relative links, such as help, search, contents, and the like.
	echo '
	<link rel="help" href="', $scripturl, '?action=help" />
	<link rel="search" href="' . $scripturl . '?action=search" />
	<link rel="contents" href="', $scripturl, '" />';

	// If RSS feeds are enabled, advertise the presence of one.
	if (!empty($modSettings['xmlnews_enable']))
		echo '
	<link rel="alternate" type="application/rss+xml" title="', $context['forum_name'], ' - RSS" href="', $scripturl, '?type=rss;action=.xml" />';

	// If we're viewing a topic, these should be the previous and next topics, respectively.
	if (!empty($context['current_topic']))
		echo '
	<link rel="prev" href="', $scripturl, '?topic=', $context['current_topic'], '.0;prev_next=prev" />
	<link rel="next" href="', $scripturl, '?topic=', $context['current_topic'], '.0;prev_next=next" />';

	// If we're in a board, or a topic for that matter, the index will be the board's index.
	if (!empty($context['current_board']))
		echo '
	<link rel="index" href="' . $scripturl . '?board=' . $context['current_board'] . '.0" />';

	// We'll have to use the cookie to remember the header...
	if ($context['user']['is_guest'])
		$options['collapse_header'] = !empty($_COOKIE['upshrink']);

	// Output any remaining HTML headers. (from mods, maybe?)
	echo $context['html_headers'], '

	<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[
		// Create the main header object.
		var mainHeader = new smfToggle("upshrink", ', empty($options['collapse_header']) ? 'false' : 'true', ');
		mainHeader.useCookie(', $context['user']['is_guest'] ? 1 : 0, ');
		mainHeader.setOptions("collapse_header", "', $context['session_id'], '");
		mainHeader.addToggleImage("upshrink", "/upshrink.gif", "/upshrink2.gif");
		mainHeader.addTogglePanel("upshrinkHeader");
		mainHeader.addTogglePanel("upshrinkHeader2");
	// ]]></script>';

	echo '
</head>
<body>';
}

function template_body_above()
{
	global $context, $settings, $options, $scripturl, $txt, $modSettings;

	echo '
            <div id="sag1">
             <div id="sol1">
              <div id="alt1">
               <div id="altsag1">
                <div id="altsol1">
	           <div id="ust1">
	            <div id="ustsag1">
	             <div id="ustsol1">
	              <div id="header">
	               <div id="head-l">
	                <div id="head-r">
	                 <div id="userarea">';

	// If the user is logged in, display stuff like their name, new messages, etc.
	if ($context['user']['is_logged'])
	{
		echo '
			 <a href="', $scripturl, '?action=unread">', $txt['unread_since_visit'], '</a> <br />
			 <a href="', $scripturl, '?action=unreadreplies">', $txt['show_unread_replies'], '</a><br />';

	}
	// Otherwise they're a guest - send them a lovely greeting...
	else
		echo sprintf($txt['welcome_guest'], $txt['guest_title']);

	// Now, onto our second set of info, are they logged in again?
	if ($context['user']['is_logged'])
	{
		// Is the forum in maintenance mode?
		if ($context['in_maintenance'] && $context['user']['is_admin'])
			echo '
				<b>', $txt['maintain_mode_on'], '</b><br />';

		// Are there any members waiting for approval?
		if (!empty($context['unapproved_members']))
			echo '
				', $context['unapproved_members'] == 1 ? $txt['approve_thereis'] : $txt['approve_thereare'], ' <a href="', $scripturl, '?action=admin;area=viewmembers;sa=browse;type=approve">', $context['unapproved_members'] == 1 ? $txt['approve_member'] : $context['unapproved_members'] . ' ' . $txt['approve_members'], '</a> ', $txt['approve_members_waiting'], '<br />';

		// Show the total time logged in?
		if (!empty($context['user']['total_time_logged_in']))
		{
			echo '
				', $txt['totalTimeLogged1'], '<br />';

			// If days is just zero, don't bother to show it.
			if ($context['user']['total_time_logged_in']['days'] > 0)
				echo $context['user']['total_time_logged_in']['days'] . $txt['totalTimeLogged2'];

			// Same with hours - only show it if it's above zero.
			if ($context['user']['total_time_logged_in']['hours'] > 0)
				echo $context['user']['total_time_logged_in']['hours'] . $txt['totalTimeLogged3'];

			// But, let's always show minutes - Time wasted here: 0 minutes ;).
			echo $context['user']['total_time_logged_in']['minutes'], $txt['totalTimeLogged4'], '<br />';
		}

		if (!empty($context['open_mod_reports']) && $context['show_open_reports'])
			echo '
				<a href="', $scripturl, '?action=moderate;area=reports">', sprintf($txt['mod_reports_waiting'], $context['open_mod_reports']), '</a><br />';
	}
	// Otherwise they're a guest - this time ask them to either register or login - lazy bums...
	else
	{
		echo '				
			<script language="JavaScript" type="text/javascript" src="', $settings['default_theme_url'], '/scripts/sha1.js"></script>

				<form action="', $scripturl, '?action=login2" method="post" accept-charset="', $context['character_set'], '" class="middletext" style="margin: 3px 1ex 1px 0;"', empty($context['disable_login_hashing']) ? ' onsubmit="hashLoginPassword(this, \'' . $context['session_id'] . '\');"' : '', '>
					<input type="text" name="user" size="10" /> <input type="password" name="passwrd" size="10" />
					<select name="cookielength">
						<option value="60">', $txt['one_hour'], '</option>
						<option value="1440">', $txt['one_day'], '</option>
						<option value="10080">', $txt['one_week'], '</option>
						<option value="43200">', $txt['one_month'], '</option>
						<option value="-1" selected="selected">', $txt['forever'], '</option>
					</select>
					<input type="submit" value="', $txt['login'], '" /><br />
					<span class="middletext">', $txt['quick_login_dec'], '</span>';
		                         if (!empty($modSettings['enableOpenID']))
		echo'<br />
					<input type="text" name="openid_url" id="openid_url" size="25" class="openid_login" />';

		echo '
					<input type="hidden" name="hash_passwrd" value="" />
				</form>';
	}
	echo '
	</div>

		<a href="'.$scripturl.'?action=forum" title=""><span id="logo"> </span></a>';
		echo '
	  </div>		 
	 </div>
	</div>
	<div id="navarea">
		<div id="nav">',template_menu(),'</div>
	</div>';
echo '
	  <div id="mainarea">
		 <div id="navarea1">
		  <div id="arama">
			    <form action="', $scripturl, '?action=search2" method="post" accept-charset="', $context['character_set'], '">
			    <input class="inputbox" type="text" name="search" value="', $txt['search'], '..." onfocus="this.value = \'\';" onblur="if(this.value==\'\') this.value=\'', $txt['search'], '...\';" />';

			// Search within current topic?
			if (!empty($context['current_topic']))
			echo '
				<input type="hidden" name="topic" value="', $context['current_topic'], '" />';
	
			// If we're on a certain board, limit it to this board ;).
			elseif (!empty($context['current_board']))
			echo '
				<input type="hidden" name="brd[', $context['current_board'], ']" value="', $context['current_board'], '" />';

			echo '
			      </form>
		    </div>
                <div id="renk">
                      <form action="',$_SERVER['REQUEST_URI'],'" method="post" class="smalltext">
                        <input style="border: solid 1px #ffffff; background-color: #888888; color: #CC4D16; width: 17px; font-size: 1px;" type="submit" value="grey" name="options[theme_color]"/>
                        <input style="border: solid 1px #ffffff; background-color: #ffff00; color: #CC4D16; width: 17px; font-size: 1px;" type="submit" value="yellow" name="options[theme_color]"/>
                        <input style="border: solid 1px #ffffff; background-color: #ff0000; color: #CC4D16; width: 17px; font-size: 1px;" type="submit" value="red" name="options[theme_color]"/>
                        <input style="border: solid 1px #ffffff; background-color: #f5f8f8; color: #5E639B; width: 17px; font-size: 1px;" type="submit" value="white" name="options[theme_color]"/>
                        <input style="border: solid 1px #ffffff; background-color: #B444BB; color: #5E639B; width: 17px; font-size: 1px;" type="submit" value="purple" name="options[theme_color]"/>
                        <input style="border: solid 1px #ffffff; background-color: #5B8A00; color: #5B8A00; width: 17px; font-size: 1px;" type="submit" value="green" name="options[theme_color]"/>
                        <input style="border: solid 1px #ffffff; background-color: #61CDF5; color: #BCCDD5; width: 17px; font-size: 1px;" type="submit" value="blue" name="options[theme_color]"/>
                        <input style="border: solid 1px #ffffff; background-color: #DC4702; color: #BCCDD5; width: 17px; font-size: 1px;" type="submit" value="orange" name="options[theme_color]"/>
                        <input style="border: solid 1px #ffffff; background-color: #732711; color: #BCCDD5; width: 17px; font-size: 1px;" type="submit" value="brown" name="options[theme_color]"/>
                        <input style="border: solid 1px #ffffff; background-color: #B3C3CF; color: #BCCDD5; width: 17px; font-size: 1px;" type="submit" value="extra" name="options[theme_color]"/>
                        <input style="border: solid 1px #ffffff; background-color: #888154; color: #BCCDD5; width: 17px; font-size: 1px;" type="submit" value="extra2" name="options[theme_color]"/>
                        <input style="border: solid 1px #ffffff; background-color: #5F2E7F; color: #BCCDD5; width: 17px; font-size: 1px;" type="submit" value="extra3" name="options[theme_color]"/>
                     </form>
                </div>';
	      echo '
			<div id="news">
			   ', theme_linktreeb(), '
		      </div>
			</div><br />';

}

function template_body_below()
{
	global $context, $settings, $options, $scripturl, $txt;

		  echo '	
	</div><br />';


	// Show the "Powered by" and "Valid" logos, as well as the copyright. Remember, the copyright must be somewhere!
	echo '
		<div id="footer">
	        <div id="foot-l">
	          <div id="foot-r">
			<div id="footerarea">
				<span class="smalltext">', theme_copyright(), '<br /><font color="#999999">Theme </font><font color="#999999"><b>Extreme6 By</b></font> <a href="http://www.fussilet.com" target="_blank">Fussilet</a></span>
</div></div></div></div>';

		// Show the load time?
	if ($context['show_load_time'])
		echo '
		<span class="smalltext">', $txt['page_created'], $context['load_time'], $txt['seconds_with'], $context['load_queries'], $txt['queries'], '</span>';

	echo '';
}

function template_html_below()
{
	global $context, $settings, $options, $scripturl, $txt, $modSettings;

	echo '
	 </div>
      </div>
     </div>
    </div>
   </div>
  </div>
 </div>
</div>
</body></html>';
}

// Show a linktree. This is that thing that shows "My Community | General Category | General Discussion"..
function theme_linktree()
{
	return;
}

// Show a linktree. This is that thing that shows "My Community | General Category | General Discussion"..
function theme_linktreeb()
{
	global $context, $settings, $options;

	echo '<div id="linktree">';
	// Each tree item has a URL and name. Some may have extra_before and extra_after.
	foreach ($context['linktree'] as $link_num => $tree)
	{
		// Don't show a separator for the last one.
		if ($link_num != count($context['linktree']) - 1)
		{
			// Show something before the link?
			if (isset($tree['extra_before']))
				echo $tree['extra_before'];

			// Show the link, including a URL if it should have one.
			echo $settings['linktree_link'] && isset($tree['url']) ? '<a href="' . $tree['url'] . '">' . $tree['name'] . '</a>' : $tree['name'];

			// Show something after the link...?
			if (isset($tree['extra_after']))
				echo $tree['extra_after'];
			echo ' &nbsp;<img class="inlineimg" src="' . $settings['images_url'] . '/linktree2.png" alt="+" border="0" />&nbsp; ';
		}
		else
			// Show the link, including a URL if it should have one.
			echo $settings['linktree_link'] && isset($tree['url']) ? '<h2><a href="' . $tree['url'] . '">' . $tree['name'] . '</a></h2>' : '<h2>'.$tree['name'].'</h2>';
		
	}
	echo '</div>';

}
// Show the menu up top. Something like [home] [help] [profile] [logout]...
function template_menu()
{
	global $context, $settings, $options, $scripturl, $txt;

	echo '
			<ul>';

			foreach ($context['menu_buttons'] as $act => $button)
				echo '<li><a ', $button['active_button'] ? ' class="current"' : '' , ' href="', $button['href'], '">', $button['title'], '</a></li>';

	echo '
			</ul>';

}

// Generate a strip of buttons.
function template_button_strip($button_strip, $direction = 'top', $force_reset = false, $custom_td = '')
{
	global $settings, $context, $txt, $scripturl;

	// Create the buttons...
	$buttons = array();
	foreach ($button_strip as $key => $value)
	{
		if (!isset($value['test']) || !empty($context[$value['test']]))
			$buttons[] = '<a href="' . $value['url'] . '" ' . (isset($value['custom']) ? $value['custom'] : '') . '><span>' . $txt[$value['text']] . '</span></a>';
	}

	if (empty($buttons))
		return '';

	// Make the last one, as easy as possible.
	$buttons[count($buttons) - 1] = str_replace('<span>', '<span class="last">', $buttons[count($buttons) - 1]);

	echo '
		<div class="buttonlist', $direction != 'top' ? '_bottom' : '', '">
			<ul class="clearfix">
				<li>', implode('</li><li>', $buttons), '</li>
			</ul>
		</div>';

}
?>
